@@ -1,7 +1,7 @@
 from logging import getLogger, Formatter, DEBUG, WARNING, StreamHandler
 
 default_logger = getLogger()
-default_logger.setLevel(DEBUG)
+default_logger.setLevel(WARNING)
 
 log_console = StreamHandler()
 log_format = '%(name)-12s %(levelname)-7s %(message)s'
